@@ -18,6 +18,8 @@
 #' @param pop population type, "MPP" (multi-parental population), 
 #' "2PP" (2 parents), "RIL" (recombinant inbred line)
 #' @param n_cores The number of cores. Defaults to 4.
+#' @param results_path Optional path to where temporary files will be saved. 
+#' If NULL, the path is taken from data_obj$results_path.
 #' 
 #' @details This uses the function probs_doqtl_to_qtl2 
 #' from qtl2convert:
@@ -39,15 +41,10 @@
 #' @import qtl2convert
 #' @importFrom qtl2 calc_kinship genoprob_to_alleleprob
 #' @importFrom utils combn
-#' 
-#' @examples 
-#' \dontrun{
-#' K <- kinship(data_obj, geno_obj)
-#' }
 #'
 #' @export
 kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4, 
-  pop=c("MPP","2PP","RIL")){
+  pop=c("MPP","2PP","RIL"), results_path = NULL){
   #file input could be geno_obj or genoprobs
   
   
@@ -88,9 +85,9 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
     
     #data_obj$save_rds(map,"map.RDS")
     
-    genoprobs <- probs_doqtl_to_qtl2(geno_obj,map=map,pos_column = "pos") #creates genotype probabilities from DOqtl...can only be used for DO genotype file
+    genoprobs <- qtl2convert::probs_doqtl_to_qtl2(geno_obj,map=map,pos_column = "pos") #creates genotype probabilities from DOqtl...can only be used for DO genotype file
     
-    genoprobs <- genoprob_to_alleleprob(genoprobs)
+    genoprobs <- qtl2::genoprob_to_alleleprob(genoprobs)
   }
   
   
@@ -103,27 +100,37 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
   if(!("calc_genoprob" %in% class_geno) && locus=="char" && pop=="MPP"){
     
     ### create map and genoprobs using geno file
-    map <- data.frame(marker = data_obj$geno_names[[3]],chr = data_obj$geno_names[[3]], 
-    		pos = data_obj$geno_names[[3]], stringsAsFactors = F)
+    non_query_idx <- which(data_obj$geno_names[[3]] != "query")
+
+    map <- data.frame(marker = data_obj$geno_names[[3]][non_query_idx],
+        chr = data_obj$geno_names[[3]][non_query_idx], 
+    		pos = data_obj$geno_names[[3]][non_query_idx], 
+        stringsAsFactors = F)
     
-    map$marker <- as.list(data_obj$geno_names$locus)
-    
-    map$chr <- as.list(data_obj$chromosome)
-    
-    map$pos <- as.list(data_obj$marker_location)
+    map$marker <- as.list(data_obj$geno_names$locus[non_query_idx])    
+    map$chr <- as.list(data_obj$chromosome[non_query_idx])
+    map$pos <- as.list(data_obj$marker_location[non_query_idx])
     
     #data_obj$save_rds(map,"map.RDS")
     
-    genoprobs <- probs_doqtl_to_qtl2(geno_obj,map=map,pos_column = "pos") #creates genotype probabilities from DOqtl...can only be used for DO genotype file
+    genoprobs <- qtl2convert::probs_doqtl_to_qtl2(geno_obj[,,non_query_idx], map = map, pos_column = "pos") #creates genotype probabilities from DOqtl...can only be used for DO genotype file
     
-    genoprobs <- genoprob_to_alleleprob(genoprobs)
+    genoprobs <- qtl2::genoprob_to_alleleprob(genoprobs)
     
   }
   
   # The QTL format file is a temporary object for transferring population data to R.qtl
   qtl_file <- "QTL_format.csv"
-  qtl_path <- data_obj$results_path
-  
+  qtl_path <- results_path
+
+  if(is.null(results_path)){
+    qtl_path <- data_obj$results_path
+  }
+
+  if(is.null(qtl_path)){
+    stop("Please provide a path for saving the output file.")
+  }
+
   ##############################################################
   #                                                            #
   #          Create probability and map file if RIL            #
@@ -131,14 +138,14 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
   ##############################################################
   if(!("calc_genoprob" %in% class_geno) && pop=="RIL"){
     write_population(data_obj, geno_obj, filename = file.path(qtl_path, qtl_file), na = "")
-    cross <- read.cross(format="csv", dir = qtl_path, qtl_file, genotypes=c(0,.5,1))
+    cross <- qtl::read.cross(format="csv", dir = qtl_path, qtl_file, genotypes=c(0,0.5,1))
     unlink(file.path(qtl_path, qtl_file)) #delete the file
-    cross <- convert2risib(cross)
-    cross <- jittermap(cross)
-    qtlprobs <- calc_genoprob(cross)
-    probs <- probs_qtl_to_qtl2(qtlprobs)
-    genoprobs <- probs$probs
-    map <- probs$map
+    map <- lapply(cross$geno, function(x) x$map)
+    map <- map[which(names(map) != 0)]
+    cross <- qtl::convert2risib(cross)
+    cross <- qtl::jittermap(cross)
+    cross2 <- qtl2::convert2cross2(cross)
+    genoprobs <- qtl2::calc_genoprob(cross2)
   }
   
   ##############################################################
@@ -149,10 +156,10 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
   if(!("calc_genoprob" %in% class_geno) && pop=="2PP"){
     write_population(data_obj, geno_obj, filename = file.path(qtl_path, qtl_file), 
     na = "")
-    cross <- read.cross(format="csv", dir = qtl_path, qtl_file, genotypes=c(0,.5,1))
+    cross <- qtl::read.cross(format="csv", dir = qtl_path, qtl_file, genotypes=c(0,.5,1))
     unlink(file.path(qtl_path, qtl_file)) #delete the file
-    qtlprobs <- calc_genoprob(cross)
-    probs <- probs_qtl_to_qtl2(qtlprobs)
+    qtlprobs <- qtl2::calc_genoprob(cross)
+    probs <- qtl2convert::probs_qtl_to_qtl2(qtlprobs)
     genoprobs <- probs$probs
     map <- probs$map
   }
@@ -174,11 +181,11 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
         stop("Must be type overall")
       }
 
-      map <- map_df_to_list(map,pos_column = "pos")
+      map <- qtl2convert::map_df_to_list(map,pos_column = "pos")
       
       #data_obj$save_rds(map,"map.RDS")
       
-      K <- calc_kinship(probs=genoprobs,type=type, cores=n_cores)
+      K <- qtl2::calc_kinship(probs=genoprobs,type=type, cores=n_cores)
     }
     
     
@@ -197,7 +204,7 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
         stop("Must be type overall")
       }
       
-      kinship <- calc_kinship(probs=genoprobs,type=type, cores=n_cores)
+      kinship <- qtl2::calc_kinship(probs=genoprobs,type=type, cores=n_cores)
       rownames(kinship) <- colnames(kinship) <- rownames(data_obj$pheno)
       K <- list(kinship)
       names(K)[1] <- "overall"
@@ -210,7 +217,7 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
     if ("calc_genoprob" %in% file_class){
       
       ## Convert to allele probabilities if it isn't a 2PP 
-      if(pop=="MPP"){ genoprobs<-genoprob_to_alleleprob(genoprobs)}
+      if(pop=="MPP"){ genoprobs <- qtl2::genoprob_to_alleleprob(genoprobs)}
       
       if(type=="chr"){
         stop("Must be type overall")
@@ -219,7 +226,7 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
         stop("Must be type overall")
       }
       
-      kinship <- calc_kinship(probs=genoprobs,type=type, cores=n_cores)
+      kinship <- qtl2::calc_kinship(probs = genoprobs,type = type, cores = n_cores)
       rownames(kinship) <- colnames(kinship) <- rownames(data_obj$pheno)
       K <- list(kinship)
       names(K)[1] <- "overall"
@@ -257,7 +264,7 @@ kinship <- function(data_obj, geno_obj, type=c("overall"), n_cores=4,
       
       # calculate kinship matrix with some chromosomes excluded
       gp <- genoprobs[,!names(genoprobs) %in% excludes[,i]]
-      kinship <- calc_kinship(probs=gp,type="overall", cores=n_cores)
+      kinship <- qtl2::calc_kinship(probs=gp,type="overall", cores=n_cores)
       
       # assign row,column names using names from the pheno object
       rownames(kinship) <- colnames(kinship) <- rownames(data_obj$pheno)
